unit MainD;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  IBServices, IBDatabase, Db, System.ComponentModel;

type
  TMainDm = class(TDataModule)
    IBConfigService: TIBConfigService;
    EmployeeDb: TIBDatabase;
    EmployeeTran: TIBTransaction;
    IBBackup: TIBBackupService;
    IBRestore: TIBRestoreService;
    IBValidate: TIBValidationService;
    IBStat: TIBStatisticalService;
    IBLog: TIBLogService;
    IBSecurity: TIBSecurityService;
    IBProperties: TIBServerProperties;
    procedure DataModuleCreate(Sender: TObject);
  private
    procedure SetCommonProperties(Service: TIBCustomService);
    procedure SetIbConfigProperties;
    procedure SetIbBackupProperties;
    procedure SetIbRestoreProperties;
    procedure SetIbValidateProperties;
    procedure SetIbStatProperties;
    { Private declarations }
  public
    { Public declarations }
  end;

var
  MainDm: TMainDm;

implementation

{$R *.DFM}

const
  IbUserName = 'sysdba';
  IbPassword = 'masterkey';
  IbProtocol = Local;
  IbServerName = 'localhost';
  IbDbName = 'employee.gdb';
  IbDbBackup = 'employee.gbk';
Var
  IbDbPath : string;  

procedure TMainDm.SetCommonProperties(Service: TIBCustomService);
begin
  with Service do
  begin
    Active := False;
    ServerName := IbServerName;
    Protocol := IbProtocol;
    LoginPrompt := False;
    Params.Clear;
    Params.Add('user_name=' + IbUserName);
    Params.Add('password=' + IbPassword);
  end; //with
end;

procedure TMainDm.SetIbConfigProperties;
begin
  with IBConfigService do
  begin
    SetCommonProperties(IBConfigService);
    DatabaseName := IbDbPath + IbDbName;
  end; //with
end;

procedure TMainDm.SetIbBackupProperties;
begin
  with IBBackup do
  begin
    SetCommonProperties(IBBackup);
    Verbose := True;
    DatabaseName := IbDbPath + IbDbName;
    BackupFile.Clear;
    BackupFile.Add(IbDbPath + IbDbBackup);
  end; //with
end;

procedure TMainDm.SetIbRestoreProperties;
begin
  with IBRestore do
  begin
    SetCommonProperties(IBRestore);
    Verbose := True;
    DatabaseName.Clear;
    DatabaseName.Add(IbDbPath + IbDbName);
    BackupFile.Clear;
    BackupFile.Add(IbDbPath + IbDbBackup);
  end; //with
end;

procedure TMainDm.SetIbValidateProperties;
begin
  with IBValidate do
  begin
    SetCommonProperties(IBValidate);
    DatabaseName := IbDbPath + IbDbName;
    Options := [ValidateDB, ValidateFull];
  end; //with
end;

procedure TMainDm.SetIbStatProperties;
begin
  with IBStat do
  begin
    SetCommonProperties(IBStat);
    DatabaseName := IbDbPath + IbDbName;
    Options := [DataPages, IndexPages];
  end; //with
end;

procedure TMainDm.DataModuleCreate(Sender: TObject);
begin
  ibDBPath := ExtractFilePath(Application.exename);
  SetIbConfigProperties;
  SetIbBackupProperties;
  SetIbRestoreProperties;
  SetIbValidateProperties;
  SetIbStatProperties;
  SetCommonProperties(IbLog);
  SetCommonProperties(IBSecurity);
  SetCommonProperties(IBProperties);
end;

end.
